--- title: "wallaroo.user" type: docs linkTitle: "wallaroo.user" ---
class User:

A platform User.

User(client, data: Dict[str, Any], standalone=False)
def id(self) -> str:
def email(self) -> str:
def username(self) -> str:
def enabled(self) -> bool:
@staticmethod
def list_users( auth, api_endpoint: str = 'http://api-lb:8080', auth_endpoint: str = 'http://api-lb:8080'):
@staticmethod
def invite_user( email, password, auth, api_endpoint: str = 'http://api-lb:8080', auth_endpoint: str = 'http://api-lb:8080'):